#!/bin/sh
set -e    # exit on error (except commands bracketed with "set +e ... set -e")
#
# Script to set up and run Gmaj for the gene-conversion pipeline.
# It uses the exons2underlays tool in the package's bin directory.
#

JAR=../gmaj.jar
CHAIN_DIR=ortho.d/ch_pair.d
#MTM_DIR=ortho.d/many-to-many-ortho.d
EXON_DIR=annot.d
E2U="../bin/exons2underlays -laj -intron Clear -fexon"
GC_FILE=./all.gc
PARAM_FILE=./gmaj.param
PREFS_FILE=./gmaj.prefs
HEAP_MB=200
SCRIPT=`echo $0 | sed -e 's;.*/;;'`    # path removed for messages

# ---- get arguments ----

if [ $# -lt 1 ] || [ $# -gt 4 ]; then
	echo "Usage:  $SCRIPT refseq_name [genomic_offset] [\"title\"] [exon_color]"
	exit 1
fi

REFNAME=$1
OFFSET=0
TITLE="Gene conversions in $1"
COLOR=LightGray

if [ $# -gt 1 ]; then
	OFFSET=$2
fi
if [ $# -gt 2 ]; then
	TITLE=$3
fi
if [ $# -gt 3 ]; then
	COLOR=$4
fi
if [ $COLOR ]; then
	if [ $COLOR = "None" ] || [ $COLOR = "none" ] || [ $COLOR = "NONE" ]; then
		COLOR=
	fi
fi

# ---- set up data files ----

SEQS=`cat $GC_FILE | grep '^[ \t]*(' -m 1 | sed -e 's;[[][^]]*[]]; ;g' | tr -s '(),;' ' '`

SELFMAF=$REFNAME.d/$REFNAME.remove_repeats.maf
#ORTHMAFS=`echo $CHAIN_DIR/$REFNAME.*.maf`    # we want tree order instead
ORTHMAFS=""
for seq in $SEQS; do
	if [ $seq != $REFNAME ]; then
		ORTHMAFS="$ORTHMAFS $CHAIN_DIR/$REFNAME.$seq.maf"
	fi
done
for seq in $SEQS; do
	if [ ! $COLOR ]; then
		:    # no underlays
	elif [ -f $EXON_DIR/$seq.underlays ]; then
		echo "Using existing underlay file $EXON_DIR/$seq.underlays"
	elif [ -f $EXON_DIR/$seq.codex ]; then
		echo "Creating underlay file $EXON_DIR/$seq.underlays from exons"
		$E2U $COLOR $EXON_DIR/$seq.codex | sed -e 's;\<intron\>;gene;g' > $EXON_DIR/$seq.underlays
	else
		echo "No annotations available in $EXON_DIR for $seq"
	fi
done

# ---- write parameters file ----

rm -f $PARAM_FILE
seqno=0
fn=

echo "#:gmaj"                              > $PARAM_FILE
echo                                       >> $PARAM_FILE
echo "title     = \"$TITLE\""              >> $PARAM_FILE
echo "alignfile = $SELFMAF $ORTHMAFS"      >> $PARAM_FILE
echo "refseq    = $REFNAME"                >> $PARAM_FILE
echo "geneconv  = $GC_FILE"                >> $PARAM_FILE
echo "nowarn    = geneconv_nomaf"          >> $PARAM_FILE
echo                                       >> $PARAM_FILE
for seq in $REFNAME $REFNAME; do
	echo "seq $seqno:"                    >> $PARAM_FILE
	seqno=`expr $seqno + 1`
	echo "seqname   = $seq"               >> $PARAM_FILE
	fn=$EXON_DIR/$seq.codex; [ -f $fn ] || fn=
	echo "exons     = $fn"                >> $PARAM_FILE
	fn=$EXON_DIR/$seq.underlays; ([ -f $fn ] && [ $COLOR ]) || fn=
	echo "underlays = $fn"                >> $PARAM_FILE
	echo "offset    = $OFFSET"            >> $PARAM_FILE
	echo                                  >> $PARAM_FILE
done
for seq in $SEQS; do
	if [ $seq != $REFNAME ]; then
		echo "seq $seqno:"               >> $PARAM_FILE
		seqno=`expr $seqno + 1`
		echo "seqname   = $seq"          >> $PARAM_FILE
		fn=$EXON_DIR/$seq.codex; [ -f $fn ] || fn=
		echo "exons     = $fn"           >> $PARAM_FILE
		fn=$EXON_DIR/$seq.underlays; ([ -f $fn ] && [ $COLOR ]) || fn=
		echo "underlays = $fn"           >> $PARAM_FILE
		echo "offset    = "              >> $PARAM_FILE
		echo                             >> $PARAM_FILE
	fi
done

# ---- run Gmaj with extra heap space, and user prefs if present ----

if [ -f $PREFS_FILE ]; then
	exec java -Xmx${HEAP_MB}m -jar $JAR -prefs $PREFS_FILE $PARAM_FILE
else
	exec java -Xmx${HEAP_MB}m -jar $JAR $PARAM_FILE
fi

